@@ -24,12 +24,14 @@
 #include <QApplication>
 #include <QIcon>
 
+#include "kamoso_version.h"
+
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
     KLocalizedString::setApplicationDomain("kamoso");
     {
-        KAboutData about("kamoso", i18n("Kamoso"), "3.2.3", i18n("Utility for taking photos and videos using a webcam"),
+        KAboutData about("kamoso", i18n("Kamoso"), KAMOSO_VERSION_STRING, i18n("Utility for taking photos and videos using a webcam"),
                          KAboutLicense::GPL, i18n("(C) 2008-2015 Alex Fiestas and Aleix Pol"));
 
         about.addAuthor( i18n("Aleix Pol Gonzalez"), i18n("Semaphore hacker"), "aleixpol@kde.org" );
